@@ -270,28 +270,6 @@ def is_iterable(obj: Any) -> bool:
         return False
     return isinstance(obj, Iterable)
 
-""" self.__version__ = '0.3.1'
-
-NOTE 0.3.1
-- A decent working state excepting escaping and subsitutions, which have not been tested
-- can set _default during instantiation only; default: _default=None
-  - accessing a non-existent attribute returns _default instead of raising AttributeError
-  - setting ._strict=1 raises AttributeError if attribute not found
-  - setting ._strict=1 after instantiation has no effect on child nodes (can fix with @property def _strict)
-- access nested data structs with dot notation and _listindex for lists
-- use ._ to get fully resolved data structure otherwise ._val is the scalar value if set
-  and its Dotc objects all the way down
-- shared attrs is no longer a problem
-- got rid of all of the printed AttributeErrors except when _debug > 1
-
-TODO:
-- sort bug printing by levels
-- fix _strict not being propagated to child nodes
-- convert all applicable methods to @property(s)
-- need unit tests
-- need consistent prms in all the _ methods
-
-"""
 class Dotc:
     """ Converts Python Data Structures (dicts, lists, scalars) to a nested object structure
     - can access nested data with dot notation and _listindex for lists
@@ -314,6 +292,19 @@ class Dotc:
             d.b._ returns {'c':3,'d':[4,5,6]} where as d.b returns the Dotc object itself so that:
             d.b.d._ returns [4,5,6]
     """
+    def __new__(cls, data=None, node=None, default=None, **kw):
+        # Check if both data and _pathget are provided for tuple return
+        _pathget = kw.get('_pathget') or kw.get('pathget')
+        
+        if data is not None and _pathget is not None:
+            # Create instance normally
+            instance = super().__new__(cls)
+            # We'll handle the tuple return using a factory method approach
+            return cls._spawn(data, node, default, _pathget, **kw)
+        
+        # Normal instantiation
+        return super().__new__(cls)
+    
     def __init__(self, data=None, node=None, default=None, **kw):
         self._debug = int(kw.pop('_debug', 0)) or int(kw.pop('debug', 0))
         self._prefix = kw.pop('_prefix', '_')
@@ -324,10 +315,9 @@ class Dotc:
         self._sub = kw.pop('_sub', '~~~')
         self._default = default if default is not None else kw.pop('_default', None)
         self._strict = kw.pop('_strict', 0)  # if 1, then setting a value on a non-existent path raises an exception
-        self._val = kw.pop('_val', None) # this is for scalar data or result of a data path get
 
         self._attrs = ['_version','_debug','_prefix','_sepr','_onebased','_node','_parent','_esc','_sub']
-        self._attrs += ['_default','_strict']
+        self._attrs += ['_default','_strict','_path','_pathget']
         self._methods_primary = ['_get', '_get_val', '_get_data', '_set', '_set_val', '_set_data', '_data', '_to_pathdict']
         self._methods_other = ['_show', '_to_lsprms', '_is_scalar', '_is_list_index', '_get_data_keys', '_get_list_keys', '_get_dict_keys']
         self._methods_other += ['_is_empty_dotc', '_resolve', '_clear_data_attributes']
@@ -338,11 +328,14 @@ class Dotc:
 
         # self._ will be a reserved method for resolving all data within a dotc object
         self._clear_data_attributes()
-        self._node = node if node is not None else kw.pop('_node', '')
+        self._val = kw.pop('_val', None) # this is for scalar data or result of a data path get
+        self._node = node if node is not None else kw.pop('_node', 'root')
         _data = kw.pop('_data', None)
         data = _data if _data is not None else data
         if data is not None:
             self._set_data(data)
+        self._path = kw.pop('_path', self._node if self._node else '')
+        self._pathget = kw.pop('_pathget', None)
 
     def __repr__(self):
         return f'Dotc( "{self._node}", _val={repr(self._val)}, _key_ct={len(self._get_dict_keys())}, _ls_ct={len(self._get_list_keys())} )'
@@ -357,11 +350,25 @@ class Dotc:
         #    return object.__getattribute__(self, '_resolve')()
 
         try:
-            strict = object.__getattribute__(self, '_strict')
-            default = object.__getattribute__(self, '_default')
-            debug = object.__getattribute__(self, '_debug')
             attr = object.__getattribute__(self, name)
+            return attr
         except AttributeError:
+            # Try to get the control attributes, but handle case where they don't exist yet
+            try:
+                strict = object.__getattribute__(self, '_strict')
+            except AttributeError:
+                strict = 0
+            
+            try:
+                default = object.__getattribute__(self, '_default')
+            except AttributeError:
+                default = None
+                
+            try:
+                debug = object.__getattribute__(self, '_debug')
+            except AttributeError:
+                debug = 0
+                
             msg = f'warning: AttributeError caught (could just be part of backfilling missing containers): {name=}, {strict=}, {default=}'
             if int(debug) > 1:
                 print(msg)
@@ -370,11 +377,35 @@ class Dotc:
             else:
                 return default
 
-        # This uses the default attribute lookup.
-        if hasattr(attr, '_val') and attr._val is not default:
-            return attr._val
+    def __call__(self, path=None):
+        if not isinstance(path, (str, bytes)) or not path:
+            return self._default
+        data = self._resolve()
+        res = DataPath.get(path, data, self._default, self._sepr, self._onebased, self._esc, self._sub, self._debug)
+        return res
 
-        return attr
+    @classmethod
+    def _spawn(cls, data, node=None, default=None, pathget=None, **kw):
+        """
+        Internal factory method that creates a Dotc instance and returns (instance, result) tuple.
+        Used when both data and _pathget/_pathget are provided during instantiation.
+        """
+        # Remove pathget from kwargs to avoid duplicate processing
+        kw.pop('_pathget', None)
+        kw.pop('pathget', None)
+        
+        # Create instance normally but bypass __new__ to avoid recursion
+        instance = super(Dotc, cls).__new__(cls)
+        instance.__init__(data, node, default, **kw)
+        
+        # Get the result using the pathget
+        if pathget:
+            result = instance(pathget)
+        else:
+            result = instance._default
+            
+        return instance, result
+    
 
     @property
     def _(self):
@@ -833,35 +864,3 @@ class Dotc:
             return res
 
 
-
-
-class TestAttr:
-
-    def __init__(self, **kw):
-        self._strict = kw.pop('_strict', 0)  # if 1, then setting a value on a non-existent path raises an exception
-        self._default = kw.pop('_default', None)
-        self._val = kw.pop('_val', None) # this is for scalar data or result of a data path get
-
-    def __getattribute__(self, name):
-        # Always use object.__getattribute__ to avoid recursion.
-        # This will get the attribute from the parent class (object)
-        # without calling this method again.
-        if name == '_val':
-            return object.__getattribute__(self, name)
-
-        try:
-            strict = object.__getattribute__(self, '_strict')
-            default = object.__getattribute__(self, '_default')
-            attr = object.__getattribute__(self, name)
-        except AttributeError:
-            #raise
-            if strict:
-                raise AttributeError(f'Attribute {name} not found in Dotc object and _strict is set')
-            else:
-                return default
-
-        # This uses the default attribute lookup.
-        if hasattr(attr, '_val') and attr._val is not default:
-            return attr._val
-
-        return attr
